@@ -1,5 +1,5 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2016 openpyxl
+# Copyright (c) 2010-2017 openpyxl
 
 """Manage individual cells in a spreadsheet.
 
@@ -53,7 +53,7 @@ TIME_TYPES = (datetime.datetime, datetime.date, datetime.time, datetime.timedelt
 STRING_TYPES = (basestring, unicode, bytes)
 KNOWN_TYPES = NUMERIC_TYPES + TIME_TYPES + STRING_TYPES + (bool, type(None))
 
-PERCENT_REGEX = re.compile(r'^\-?(?P<number>[0-9]*\.?[0-9]*\s?)\%$')
+PERCENT_REGEX = re.compile(r'^(?P<number>\-?[0-9]*\.?[0-9]*\s?)\%$')
 TIME_REGEX = re.compile(r"""
 ^(?: # HH:MM and HH:MM:SS
 (?P<hour>[0-1]{0,1}[0-9]{2}):
@@ -139,7 +139,7 @@ class Cell(StyleableObject):
         return getattr(self.parent.parent, 'guess_types', False)
 
     def __repr__(self):
-        return unicode("<Cell %s.%s>") % (self.parent.title, self.coordinate)
+        return "<Cell {0!r}.{1}>".format(self.parent.title, self.coordinate)
 
     def check_string(self, value):
         """Check string coding, length, and line break character"""
@@ -198,7 +198,7 @@ class Cell(StyleableObject):
                 value = self._infer_value(value)
 
         elif value is not None:
-            raise ValueError("Cannot convert {0} to Excel".format(value))
+            raise ValueError("Cannot convert {0!r} to Excel".format(value))
 
         self._value = value
 
@@ -279,8 +279,10 @@ class Cell(StyleableObject):
     @property
     def value(self):
         """Get or set the value held in the cell.
-            ':rtype: depends on the value (string, float, int or '
-            ':class:`datetime.datetime`)'"""
+
+        :rtype: depends on the value (string, float, int or
+            :class:`datetime.datetime`)
+        """
         value = self._value
         if value is not None and self.is_date:
             value = from_excel(value, self.base_date)
