@@ -1,13 +1,14 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2015 openpyxl
+# Copyright (c) 2010-2017 openpyxl
 
+from math import isnan
 import sys
 
 VER = sys.version_info
 
 from .numbers import NUMERIC_TYPES
 
-if VER[0] == 3:
+if VER[0] >= 3:
     basestring = str
     unicode = str
     from io import BufferedReader
@@ -26,9 +27,21 @@ else:
 def safe_string(value):
     """Safely and consistently format numeric values"""
     if isinstance(value, NUMERIC_TYPES):
-        value = "%.16g" % value
+        if isnan(value):
+            value = ""
+        else:
+            value = "%.16g" % value
     elif value is None:
         value = "none"
     elif not isinstance(value, basestring):
         value = str(value)
     return value
+
+
+def safe_repr(value):
+    """
+    Safely convert unicode to ASCII for Python 2
+    """
+    if VER[0] == 3:
+        return value
+    return value.encode("ascii", 'backslashreplace')
