@@ -1,7 +1,10 @@
 from __future__ import absolute_import
+from __future__ import division
 # Copyright (c) 2010-2017 openpyxl
 
+from io import BytesIO
 from .drawing import Drawing
+from openpyxl.compat import deprecated
 
 
 def bounding_box(bw, bh, w, h):
@@ -13,10 +16,10 @@ def bounding_box(bw, bh, w, h):
     new_width, new_height = w, h
     if bw and new_width > bw:
         new_width = bw
-        new_height = new_width / (float(w) / h)
+        new_height = new_width / (w / h)
     if bh and new_height > bh:
         new_height = bh
-        new_width = new_height * (float(w) / h)
+        new_width = new_height * (w / h)
     return (new_width, new_height)
 
 
@@ -39,27 +42,33 @@ class Image(object):
     """ Raw Image class """
 
     _id = 1
-    _path = "/xl/media/image{0}.png"
+    _path = "/xl/media/image{0}.{1}"
 
     def __init__(self, img, coordinates=((0, 0), (1, 1)), size=(None, None),
                  nochangeaspect=True, nochangearrowheads=True):
 
-        self.image = _import_image(img)
-        self.nochangeaspect = nochangeaspect
-        self.nochangearrowheads = nochangearrowheads
+        self.ref = img
 
-        # the containing drawing
-        self.drawing = Drawing()
-        self.drawing.coordinates = coordinates
+        # don't keep the image open
+        image = _import_image(img)
+        self.format = image.format.lower()
+        self.nochangeaspect = nochangeaspect # deprecated
+        self.nochangearrowheads = nochangearrowheads # deprecated
 
         newsize = bounding_box(
             size[0], size[1],
-            self.image.size[0], self.image.size[1]
+            image.size[0], image.size[1]
         )
         size = newsize
+
+        # the containing drawing
+        self.drawing = Drawing()
+        self.drawing.coordinates = coordinates # deprecated
         self.drawing.width = size[0]
         self.drawing.height = size[1]
 
+
+    @deprecated("Anchors can be passed in when an image is added to a worksheet")
     def anchor(self, cell, anchortype="absolute"):
         """ anchors the image to the given cell
             optional parameter anchortype supports 'absolute' or 'oneCell'"""
@@ -77,6 +86,24 @@ class Image(object):
             raise ValueError("unknown anchortype %s" % anchortype)
 
 
+    def _data(self):
+        """
+        Open image and write it to a buffer when saving the workbook
+        """
+        img = _import_image(self.ref)
+        fp = None
+        # don't convert these file formats
+        if self.format in ['gif', 'jpeg', 'png']:
+            if img.fp:
+                img.fp.seek(0)
+                fp = img.fp
+        if not fp:
+            fp = BytesIO()
+            img.save(fp, format=self.format)
+
+        return fp.read()
+
+
     @property
     def path(self):
-        return self._path.format(self._id)
+        return self._path.format(self._id, self.format)
